LiveExecEngineConfig

Struct LiveExecEngineConfig 

pub struct LiveExecEngineConfig {
Show 40 fields pub load_cache: bool, pub snapshot_orders: bool, pub snapshot_positions: bool, pub snapshot_positions_interval_secs: Option<f64>, pub external_clients: Option<Vec<ClientId>>, pub debug: bool, pub reconciliation: bool, pub reconciliation_startup_delay_secs: f64, pub reconciliation_lookback_mins: Option<u32>, pub reconciliation_instrument_ids: Option<Vec<String>>, pub filter_unclaimed_external_orders: bool, pub filter_position_reports: bool, pub filtered_client_order_ids: Option<Vec<String>>, pub generate_missing_orders: bool, pub inflight_check_interval_ms: u32, pub inflight_check_threshold_ms: u32, pub inflight_check_retries: u32, pub open_check_interval_secs: Option<f64>, pub open_check_lookback_mins: Option<u32>, pub open_check_threshold_ms: u32, pub open_check_missing_retries: u32, pub open_check_open_only: bool, pub max_single_order_queries_per_cycle: u32, pub single_order_query_delay_ms: u32, pub position_check_interval_secs: Option<f64>, pub position_check_lookback_mins: u32, pub position_check_threshold_ms: u32, pub position_check_retries: u32, pub purge_closed_orders_interval_mins: Option<u32>, pub purge_closed_orders_buffer_mins: Option<u32>, pub purge_closed_positions_interval_mins: Option<u32>, pub purge_closed_positions_buffer_mins: Option<u32>, pub purge_account_events_interval_mins: Option<u32>, pub purge_account_events_lookback_mins: Option<u32>, pub purge_from_database: bool, pub own_books_audit_interval_secs: Option<f64>, pub graceful_shutdown_on_error: bool, pub qsize: u32, pub allow_overfills: bool, pub manage_own_order_books: bool,
}
Configuration for live execution engines.

Fields

load_cache: bool

If the cache should be loaded on initialization.

snapshot_orders: bool

If order state snapshot lists should be persisted to a backing database.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default because the live kernel does not yet wire a cache database adapter.

snapshot_positions: bool

If position state snapshot lists should be persisted to a backing database.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default because the live kernel does not yet wire a cache database adapter.

snapshot_positions_interval_secs: Option<f64>

The interval (seconds) at which additional position state snapshots are persisted. If None then no additional snapshots will be taken.

external_clients: Option<Vec<ClientId>>

Client IDs declared for external stream processing.

The execution engine will not attempt to send trading commands to these client IDs, assuming an external process consumes them from the bus.

debug: bool

If debug mode is active (will provide extra debug logging).

reconciliation: bool

If reconciliation is active at start-up.

reconciliation_startup_delay_secs: f64

The delay (seconds) before starting reconciliation at startup.

reconciliation_lookback_mins: Option<u32>

The maximum lookback minutes to reconcile state for.

reconciliation_instrument_ids: Option<Vec<String>>

Specific instrument IDs to reconcile (if None, reconciles all).

filter_unclaimed_external_orders: bool

If unclaimed order events with an EXTERNAL strategy ID should be filtered/dropped.

filter_position_reports: bool

If position status reports are filtered from reconciliation.

filtered_client_order_ids: Option<Vec<String>>

Client order IDs to filter from reconciliation.

generate_missing_orders: bool

If MARKET order events will be generated during reconciliation to align discrepancies.

inflight_check_interval_ms: u32

The interval (milliseconds) between checking whether in-flight orders have exceeded their threshold.

inflight_check_threshold_ms: u32

The threshold (milliseconds) beyond which an in-flight order’s status is checked with the venue.

inflight_check_retries: u32

The number of retry attempts for verifying in-flight order status.

open_check_interval_secs: Option<f64>

The interval (seconds) between checks for open orders at the venue.

open_check_lookback_mins: Option<u32>

The lookback minutes for open order checks. When None, the check is unbounded (no time filter).

open_check_threshold_ms: u32

The minimum elapsed time (milliseconds) since an order update before acting on discrepancies.

open_check_missing_retries: u32

The number of retries for missing open orders.

open_check_open_only: bool

If the check_open_orders requests only currently open orders from the venue.

max_single_order_queries_per_cycle: u32

The maximum number of single-order queries per consistency check cycle.

single_order_query_delay_ms: u32

The delay (milliseconds) between consecutive single-order queries.

position_check_interval_secs: Option<f64>

The interval (seconds) between checks for open positions at the venue.

position_check_lookback_mins: u32

The lookback minutes for position consistency checks.

position_check_threshold_ms: u32

The minimum elapsed time (milliseconds) since a position update before acting on discrepancies.

position_check_retries: u32

The maximum number of reconciliation attempts for a position discrepancy.

purge_closed_orders_interval_mins: Option<u32>

The interval (minutes) between purging closed orders from the in-memory cache.

purge_closed_orders_buffer_mins: Option<u32>

The time buffer (minutes) before closed orders can be purged.

purge_closed_positions_interval_mins: Option<u32>

The interval (minutes) between purging closed positions from the in-memory cache.

purge_closed_positions_buffer_mins: Option<u32>

The time buffer (minutes) before closed positions can be purged.

purge_account_events_interval_mins: Option<u32>

The interval (minutes) between purging account events from the in-memory cache.

purge_account_events_lookback_mins: Option<u32>

The time buffer (minutes) before account events can be purged.

purge_from_database: bool

If purge operations should also delete from the backing database.

own_books_audit_interval_secs: Option<f64>

The interval (seconds) between auditing own books against public order books.

graceful_shutdown_on_error: bool

If the engine should gracefully shutdown when queue processing encounters unexpected errors.

qsize: u32

The queue size for the engine’s internal queue buffers.

allow_overfills: bool

If order fills exceeding order quantity are allowed (logs warning instead of raising). Useful when position reconciliation races with exchange fill events.

manage_own_order_books: bool

If the execution engine should maintain own/user order books based on commands and events.

Implementations

Source

impl LiveExecEngineConfig

pub fn builder() -> LiveExecEngineConfigBuilder

Create an instance of LiveExecEngineConfig using the builder syntax