LiveExecEngineConfigBuilder

Struct LiveExecEngineConfigBuilder 

pub struct LiveExecEngineConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> LiveExecEngineConfigBuilder<S>

pub fn build(self) -> LiveExecEngineConfig
where S: IsComplete,

Finish building and return the requested object

pub fn load_cache( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetLoadCache<S>>
where S::LoadCache: IsUnset,

Optional (Some / Option setters). Default: true.

If the cache should be loaded on initialization.

pub fn maybe_load_cache( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetLoadCache<S>>
where S::LoadCache: IsUnset,

Optional (Some / Option setters). Default: true.

If the cache should be loaded on initialization.

pub fn snapshot_orders( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetSnapshotOrders<S>>
where S::SnapshotOrders: IsUnset,

Optional (Some / Option setters). Default: false.

If order state snapshot lists should be persisted to a backing database.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default because the live kernel does not yet wire a cache database adapter.

pub fn maybe_snapshot_orders( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetSnapshotOrders<S>>
where S::SnapshotOrders: IsUnset,

Optional (Some / Option setters). Default: false.

If order state snapshot lists should be persisted to a backing database.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default because the live kernel does not yet wire a cache database adapter.

pub fn snapshot_positions( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetSnapshotPositions<S>>
where S::SnapshotPositions: IsUnset,

Optional (Some / Option setters). Default: false.

If position state snapshot lists should be persisted to a backing database.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default because the live kernel does not yet wire a cache database adapter.

pub fn maybe_snapshot_positions( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetSnapshotPositions<S>>
where S::SnapshotPositions: IsUnset,

Optional (Some / Option setters). Default: false.

If position state snapshot lists should be persisted to a backing database.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default because the live kernel does not yet wire a cache database adapter.

pub fn snapshot_positions_interval_secs( self, value: f64, ) -> LiveExecEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>
where S::SnapshotPositionsIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) at which additional position state snapshots are persisted. If None then no additional snapshots will be taken.

pub fn maybe_snapshot_positions_interval_secs( self, value: Option<f64>, ) -> LiveExecEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>
where S::SnapshotPositionsIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) at which additional position state snapshots are persisted. If None then no additional snapshots will be taken.

pub fn external_clients( self, value: Vec<ClientId>, ) -> LiveExecEngineConfigBuilder<SetExternalClients<S>>
where S::ExternalClients: IsUnset,

Optional (Some / Option setters). Client IDs declared for external stream processing.

The execution engine will not attempt to send trading commands to these client IDs, assuming an external process consumes them from the bus.

pub fn maybe_external_clients( self, value: Option<Vec<ClientId>>, ) -> LiveExecEngineConfigBuilder<SetExternalClients<S>>
where S::ExternalClients: IsUnset,

Optional (Some / Option setters). Client IDs declared for external stream processing.

The execution engine will not attempt to send trading commands to these client IDs, assuming an external process consumes them from the bus.

pub fn debug(self, value: bool) -> LiveExecEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn maybe_debug( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn reconciliation( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetReconciliation<S>>
where S::Reconciliation: IsUnset,

Optional (Some / Option setters). Default: true.

If reconciliation is active at start-up.

pub fn maybe_reconciliation( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetReconciliation<S>>
where S::Reconciliation: IsUnset,

Optional (Some / Option setters). Default: true.

If reconciliation is active at start-up.

pub fn reconciliation_startup_delay_secs( self, value: f64, ) -> LiveExecEngineConfigBuilder<SetReconciliationStartupDelaySecs<S>>
where S::ReconciliationStartupDelaySecs: IsUnset,

Optional (Some / Option setters). Default: 10.0.

The delay (seconds) before starting reconciliation at startup.

pub fn maybe_reconciliation_startup_delay_secs( self, value: Option<f64>, ) -> LiveExecEngineConfigBuilder<SetReconciliationStartupDelaySecs<S>>
where S::ReconciliationStartupDelaySecs: IsUnset,

Optional (Some / Option setters). Default: 10.0.

The delay (seconds) before starting reconciliation at startup.

pub fn reconciliation_lookback_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetReconciliationLookbackMins<S>>
where S::ReconciliationLookbackMins: IsUnset,

Optional (Some / Option setters). The maximum lookback minutes to reconcile state for.

pub fn maybe_reconciliation_lookback_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetReconciliationLookbackMins<S>>
where S::ReconciliationLookbackMins: IsUnset,

Optional (Some / Option setters). The maximum lookback minutes to reconcile state for.

pub fn reconciliation_instrument_ids( self, value: Vec<String>, ) -> LiveExecEngineConfigBuilder<SetReconciliationInstrumentIds<S>>
where S::ReconciliationInstrumentIds: IsUnset,

Optional (Some / Option setters). Specific instrument IDs to reconcile (if None, reconciles all).

pub fn maybe_reconciliation_instrument_ids( self, value: Option<Vec<String>>, ) -> LiveExecEngineConfigBuilder<SetReconciliationInstrumentIds<S>>
where S::ReconciliationInstrumentIds: IsUnset,

Optional (Some / Option setters). Specific instrument IDs to reconcile (if None, reconciles all).

pub fn filter_unclaimed_external_orders( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetFilterUnclaimedExternalOrders<S>>
where S::FilterUnclaimedExternalOrders: IsUnset,

Optional (Some / Option setters). Default: false.

If unclaimed order events with an EXTERNAL strategy ID should be filtered/dropped.

pub fn maybe_filter_unclaimed_external_orders( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetFilterUnclaimedExternalOrders<S>>
where S::FilterUnclaimedExternalOrders: IsUnset,

Optional (Some / Option setters). Default: false.

If unclaimed order events with an EXTERNAL strategy ID should be filtered/dropped.

pub fn filter_position_reports( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetFilterPositionReports<S>>
where S::FilterPositionReports: IsUnset,

Optional (Some / Option setters). Default: false.

If position status reports are filtered from reconciliation.

pub fn maybe_filter_position_reports( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetFilterPositionReports<S>>
where S::FilterPositionReports: IsUnset,

Optional (Some / Option setters). Default: false.

If position status reports are filtered from reconciliation.

pub fn filtered_client_order_ids( self, value: Vec<String>, ) -> LiveExecEngineConfigBuilder<SetFilteredClientOrderIds<S>>
where S::FilteredClientOrderIds: IsUnset,

Optional (Some / Option setters). Client order IDs to filter from reconciliation.

pub fn maybe_filtered_client_order_ids( self, value: Option<Vec<String>>, ) -> LiveExecEngineConfigBuilder<SetFilteredClientOrderIds<S>>
where S::FilteredClientOrderIds: IsUnset,

Optional (Some / Option setters). Client order IDs to filter from reconciliation.

pub fn generate_missing_orders( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetGenerateMissingOrders<S>>
where S::GenerateMissingOrders: IsUnset,

Optional (Some / Option setters). Default: true.

If MARKET order events will be generated during reconciliation to align discrepancies.

pub fn maybe_generate_missing_orders( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetGenerateMissingOrders<S>>
where S::GenerateMissingOrders: IsUnset,

Optional (Some / Option setters). Default: true.

If MARKET order events will be generated during reconciliation to align discrepancies.

pub fn inflight_check_interval_ms( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetInflightCheckIntervalMs<S>>
where S::InflightCheckIntervalMs: IsUnset,

Optional (Some / Option setters). Default: 2_000.

The interval (milliseconds) between checking whether in-flight orders have exceeded their threshold.

pub fn maybe_inflight_check_interval_ms( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetInflightCheckIntervalMs<S>>
where S::InflightCheckIntervalMs: IsUnset,

Optional (Some / Option setters). Default: 2_000.

The interval (milliseconds) between checking whether in-flight orders have exceeded their threshold.

pub fn inflight_check_threshold_ms( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetInflightCheckThresholdMs<S>>
where S::InflightCheckThresholdMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

The threshold (milliseconds) beyond which an in-flight order’s status is checked with the venue.

pub fn maybe_inflight_check_threshold_ms( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetInflightCheckThresholdMs<S>>
where S::InflightCheckThresholdMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

The threshold (milliseconds) beyond which an in-flight order’s status is checked with the venue.

pub fn inflight_check_retries( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetInflightCheckRetries<S>>
where S::InflightCheckRetries: IsUnset,

Optional (Some / Option setters). Default: 5.

The number of retry attempts for verifying in-flight order status.

pub fn maybe_inflight_check_retries( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetInflightCheckRetries<S>>
where S::InflightCheckRetries: IsUnset,

Optional (Some / Option setters). Default: 5.

The number of retry attempts for verifying in-flight order status.

pub fn open_check_interval_secs( self, value: f64, ) -> LiveExecEngineConfigBuilder<SetOpenCheckIntervalSecs<S>>
where S::OpenCheckIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) between checks for open orders at the venue.

pub fn maybe_open_check_interval_secs( self, value: Option<f64>, ) -> LiveExecEngineConfigBuilder<SetOpenCheckIntervalSecs<S>>
where S::OpenCheckIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) between checks for open orders at the venue.

pub fn open_check_lookback_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetOpenCheckLookbackMins<S>>
where S::OpenCheckLookbackMins: IsUnset,

Optional (Some / Option setters). The lookback minutes for open order checks. When None, the check is unbounded (no time filter).

pub fn maybe_open_check_lookback_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetOpenCheckLookbackMins<S>>
where S::OpenCheckLookbackMins: IsUnset,

Optional (Some / Option setters). The lookback minutes for open order checks. When None, the check is unbounded (no time filter).

pub fn open_check_threshold_ms( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetOpenCheckThresholdMs<S>>
where S::OpenCheckThresholdMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

The minimum elapsed time (milliseconds) since an order update before acting on discrepancies.

pub fn maybe_open_check_threshold_ms( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetOpenCheckThresholdMs<S>>
where S::OpenCheckThresholdMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

The minimum elapsed time (milliseconds) since an order update before acting on discrepancies.

pub fn open_check_missing_retries( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetOpenCheckMissingRetries<S>>
where S::OpenCheckMissingRetries: IsUnset,

Optional (Some / Option setters). Default: 5.

The number of retries for missing open orders.

pub fn maybe_open_check_missing_retries( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetOpenCheckMissingRetries<S>>
where S::OpenCheckMissingRetries: IsUnset,

Optional (Some / Option setters). Default: 5.

The number of retries for missing open orders.

pub fn open_check_open_only( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetOpenCheckOpenOnly<S>>
where S::OpenCheckOpenOnly: IsUnset,

Optional (Some / Option setters). Default: true.

If the check_open_orders requests only currently open orders from the venue.

pub fn maybe_open_check_open_only( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetOpenCheckOpenOnly<S>>
where S::OpenCheckOpenOnly: IsUnset,

Optional (Some / Option setters). Default: true.

If the check_open_orders requests only currently open orders from the venue.

pub fn max_single_order_queries_per_cycle( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetMaxSingleOrderQueriesPerCycle<S>>
where S::MaxSingleOrderQueriesPerCycle: IsUnset,

Optional (Some / Option setters). Default: 10.

The maximum number of single-order queries per consistency check cycle.

pub fn maybe_max_single_order_queries_per_cycle( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetMaxSingleOrderQueriesPerCycle<S>>
where S::MaxSingleOrderQueriesPerCycle: IsUnset,

Optional (Some / Option setters). Default: 10.

The maximum number of single-order queries per consistency check cycle.

pub fn single_order_query_delay_ms( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetSingleOrderQueryDelayMs<S>>
where S::SingleOrderQueryDelayMs: IsUnset,

Optional (Some / Option setters). Default: 100.

The delay (milliseconds) between consecutive single-order queries.

pub fn maybe_single_order_query_delay_ms( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetSingleOrderQueryDelayMs<S>>
where S::SingleOrderQueryDelayMs: IsUnset,

Optional (Some / Option setters). Default: 100.

The delay (milliseconds) between consecutive single-order queries.

pub fn position_check_interval_secs( self, value: f64, ) -> LiveExecEngineConfigBuilder<SetPositionCheckIntervalSecs<S>>
where S::PositionCheckIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) between checks for open positions at the venue.

pub fn maybe_position_check_interval_secs( self, value: Option<f64>, ) -> LiveExecEngineConfigBuilder<SetPositionCheckIntervalSecs<S>>
where S::PositionCheckIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) between checks for open positions at the venue.

pub fn position_check_lookback_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPositionCheckLookbackMins<S>>
where S::PositionCheckLookbackMins: IsUnset,

Optional (Some / Option setters). Default: 60.

The lookback minutes for position consistency checks.

pub fn maybe_position_check_lookback_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPositionCheckLookbackMins<S>>
where S::PositionCheckLookbackMins: IsUnset,

Optional (Some / Option setters). Default: 60.

The lookback minutes for position consistency checks.

pub fn position_check_threshold_ms( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPositionCheckThresholdMs<S>>
where S::PositionCheckThresholdMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

The minimum elapsed time (milliseconds) since a position update before acting on discrepancies.

pub fn maybe_position_check_threshold_ms( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPositionCheckThresholdMs<S>>
where S::PositionCheckThresholdMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

The minimum elapsed time (milliseconds) since a position update before acting on discrepancies.

pub fn position_check_retries( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPositionCheckRetries<S>>
where S::PositionCheckRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

The maximum number of reconciliation attempts for a position discrepancy.

pub fn maybe_position_check_retries( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPositionCheckRetries<S>>
where S::PositionCheckRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

The maximum number of reconciliation attempts for a position discrepancy.

pub fn purge_closed_orders_interval_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>
where S::PurgeClosedOrdersIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed orders from the in-memory cache.

pub fn maybe_purge_closed_orders_interval_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>
where S::PurgeClosedOrdersIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed orders from the in-memory cache.

pub fn purge_closed_orders_buffer_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>
where S::PurgeClosedOrdersBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed orders can be purged.

pub fn maybe_purge_closed_orders_buffer_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>
where S::PurgeClosedOrdersBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed orders can be purged.

pub fn purge_closed_positions_interval_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>
where S::PurgeClosedPositionsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed positions from the in-memory cache.

pub fn maybe_purge_closed_positions_interval_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>
where S::PurgeClosedPositionsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed positions from the in-memory cache.

pub fn purge_closed_positions_buffer_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>
where S::PurgeClosedPositionsBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed positions can be purged.

pub fn maybe_purge_closed_positions_buffer_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>
where S::PurgeClosedPositionsBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed positions can be purged.

pub fn purge_account_events_interval_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>
where S::PurgeAccountEventsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging account events from the in-memory cache.

pub fn maybe_purge_account_events_interval_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>
where S::PurgeAccountEventsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging account events from the in-memory cache.

pub fn purge_account_events_lookback_mins( self, value: u32, ) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>
where S::PurgeAccountEventsLookbackMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before account events can be purged.

pub fn maybe_purge_account_events_lookback_mins( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>
where S::PurgeAccountEventsLookbackMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before account events can be purged.

pub fn purge_from_database( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetPurgeFromDatabase<S>>
where S::PurgeFromDatabase: IsUnset,

Optional (Some / Option setters). Default: false.

If purge operations should also delete from the backing database.

pub fn maybe_purge_from_database( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetPurgeFromDatabase<S>>
where S::PurgeFromDatabase: IsUnset,

Optional (Some / Option setters). Default: false.

If purge operations should also delete from the backing database.

pub fn own_books_audit_interval_secs( self, value: f64, ) -> LiveExecEngineConfigBuilder<SetOwnBooksAuditIntervalSecs<S>>
where S::OwnBooksAuditIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) between auditing own books against public order books.

pub fn maybe_own_books_audit_interval_secs( self, value: Option<f64>, ) -> LiveExecEngineConfigBuilder<SetOwnBooksAuditIntervalSecs<S>>
where S::OwnBooksAuditIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) between auditing own books against public order books.

pub fn graceful_shutdown_on_error( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetGracefulShutdownOnError<S>>
where S::GracefulShutdownOnError: IsUnset,

Optional (Some / Option setters). Default: false.

If the engine should gracefully shutdown when queue processing encounters unexpected errors.

pub fn maybe_graceful_shutdown_on_error( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetGracefulShutdownOnError<S>>
where S::GracefulShutdownOnError: IsUnset,

Optional (Some / Option setters). Default: false.

If the engine should gracefully shutdown when queue processing encounters unexpected errors.

pub fn qsize(self, value: u32) -> LiveExecEngineConfigBuilder<SetQsize<S>>
where S::Qsize: IsUnset,

Optional (Some / Option setters). Default: 100_000.

The queue size for the engine’s internal queue buffers.

pub fn maybe_qsize( self, value: Option<u32>, ) -> LiveExecEngineConfigBuilder<SetQsize<S>>
where S::Qsize: IsUnset,

Optional (Some / Option setters). Default: 100_000.

The queue size for the engine’s internal queue buffers.

pub fn allow_overfills( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetAllowOverfills<S>>
where S::AllowOverfills: IsUnset,

Optional (Some / Option setters). Default: false.

If order fills exceeding order quantity are allowed (logs warning instead of raising). Useful when position reconciliation races with exchange fill events.

pub fn maybe_allow_overfills( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetAllowOverfills<S>>
where S::AllowOverfills: IsUnset,

Optional (Some / Option setters). Default: false.

If order fills exceeding order quantity are allowed (logs warning instead of raising). Useful when position reconciliation races with exchange fill events.

pub fn manage_own_order_books( self, value: bool, ) -> LiveExecEngineConfigBuilder<SetManageOwnOrderBooks<S>>
where S::ManageOwnOrderBooks: IsUnset,

Optional (Some / Option setters). Default: false.

If the execution engine should maintain own/user order books based on commands and events.

pub fn maybe_manage_own_order_books( self, value: Option<bool>, ) -> LiveExecEngineConfigBuilder<SetManageOwnOrderBooks<S>>
where S::ManageOwnOrderBooks: IsUnset,

Optional (Some / Option setters). Default: false.

If the execution engine should maintain own/user order books based on commands and events.