pub struct LiveNodeConfig {Show 23 fields
pub environment: Environment,
pub trader_id: TraderId,
pub load_state: bool,
pub save_state: bool,
pub logging: LoggerConfig,
pub instance_id: Option<UUID4>,
pub timeout_connection: Duration,
pub timeout_reconciliation: Duration,
pub timeout_portfolio: Duration,
pub timeout_disconnection: Duration,
pub delay_post_stop: Duration,
pub timeout_shutdown: Duration,
pub cache: Option<CacheConfig>,
pub msgbus: Option<MessageBusConfig>,
pub portfolio: Option<PortfolioConfig>,
pub emulator: Option<OrderEmulatorConfig>,
pub streaming: Option<StreamingConfig>,
pub loop_debug: bool,
pub data_engine: LiveDataEngineConfig,
pub risk_engine: LiveRiskEngineConfig,
pub exec_engine: LiveExecEngineConfig,
pub data_clients: HashMap<String, LiveDataClientConfig>,
pub exec_clients: HashMap<String, LiveExecClientConfig>,
}Expand description
Configuration for live Nautilus system nodes.
Fields
environment: EnvironmentThe trading environment.
trader_id: TraderIdThe trader ID for the node.
load_state: boolIf trading strategy state should be loaded from the database on start.
save_state: boolIf trading strategy state should be saved to the database on stop.
logging: LoggerConfigThe logging configuration for the kernel.
instance_id: Option<UUID4>The unique instance identifier for the kernel
timeout_connection: DurationThe timeout for all clients to connect and initialize.
timeout_reconciliation: DurationThe timeout for execution state to reconcile.
timeout_portfolio: DurationThe timeout for portfolio to initialize margins and unrealized pnls.
timeout_disconnection: DurationThe timeout for all engine clients to disconnect.
delay_post_stop: DurationThe delay after stopping the node to await residual events before final shutdown.
timeout_shutdown: DurationThe timeout to await pending tasks cancellation during shutdown.
cache: Option<CacheConfig>The cache configuration.
msgbus: Option<MessageBusConfig>The message bus configuration.
portfolio: Option<PortfolioConfig>The portfolio configuration.
emulator: Option<OrderEmulatorConfig>The order emulator configuration.
streaming: Option<StreamingConfig>The configuration for streaming to feather files.
loop_debug: boolIf the asyncio event loop should run in debug mode.
data_engine: LiveDataEngineConfigThe live data engine configuration.
risk_engine: LiveRiskEngineConfigThe live risk engine configuration.
exec_engine: LiveExecEngineConfigThe live execution engine configuration.
data_clients: HashMap<String, LiveDataClientConfig>The data client configurations.
exec_clients: HashMap<String, LiveExecClientConfig>The execution client configurations.
Implementations
Sourceimpl LiveNodeConfig
impl LiveNodeConfig
Sourcepub fn builder() -> LiveNodeConfigBuilder
pub fn builder() -> LiveNodeConfigBuilder
Create an instance of LiveNodeConfig using the builder syntax