LiveRiskEngineConfigBuilder

Struct LiveRiskEngineConfigBuilder 

pub struct LiveRiskEngineConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> LiveRiskEngineConfigBuilder<S>

pub fn build(self) -> LiveRiskEngineConfig
where S: IsComplete,

Finish building and return the requested object

pub fn bypass(self, value: bool) -> LiveRiskEngineConfigBuilder<SetBypass<S>>
where S::Bypass: IsUnset,

Optional (Some / Option setters). Default: false.

If all pre-trade risk checks should be bypassed.

pub fn maybe_bypass( self, value: Option<bool>, ) -> LiveRiskEngineConfigBuilder<SetBypass<S>>
where S::Bypass: IsUnset,

Optional (Some / Option setters). Default: false.

If all pre-trade risk checks should be bypassed.

pub fn max_order_submit_rate( self, value: String, ) -> LiveRiskEngineConfigBuilder<SetMaxOrderSubmitRate<S>>
where S::MaxOrderSubmitRate: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_ORDER_RATE_LIMIT.to_string().

The maximum submit order rate as limit/HH:MM:SS.

pub fn maybe_max_order_submit_rate( self, value: Option<String>, ) -> LiveRiskEngineConfigBuilder<SetMaxOrderSubmitRate<S>>
where S::MaxOrderSubmitRate: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_ORDER_RATE_LIMIT.to_string().

The maximum submit order rate as limit/HH:MM:SS.

pub fn max_order_modify_rate( self, value: String, ) -> LiveRiskEngineConfigBuilder<SetMaxOrderModifyRate<S>>
where S::MaxOrderModifyRate: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_ORDER_RATE_LIMIT.to_string().

The maximum modify order rate as limit/HH:MM:SS.

pub fn maybe_max_order_modify_rate( self, value: Option<String>, ) -> LiveRiskEngineConfigBuilder<SetMaxOrderModifyRate<S>>
where S::MaxOrderModifyRate: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_ORDER_RATE_LIMIT.to_string().

The maximum modify order rate as limit/HH:MM:SS.

pub fn max_notional_per_order( self, value: HashMap<String, String>, ) -> LiveRiskEngineConfigBuilder<SetMaxNotionalPerOrder<S>>
where S::MaxNotionalPerOrder: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

The maximum notional per order keyed by instrument ID.

Entries map instrument ID strings to decimal notional strings.

pub fn maybe_max_notional_per_order( self, value: Option<HashMap<String, String>>, ) -> LiveRiskEngineConfigBuilder<SetMaxNotionalPerOrder<S>>
where S::MaxNotionalPerOrder: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

The maximum notional per order keyed by instrument ID.

Entries map instrument ID strings to decimal notional strings.

pub fn debug(self, value: bool) -> LiveRiskEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn maybe_debug( self, value: Option<bool>, ) -> LiveRiskEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn graceful_shutdown_on_error( self, value: bool, ) -> LiveRiskEngineConfigBuilder<SetGracefulShutdownOnError<S>>
where S::GracefulShutdownOnError: IsUnset,

Optional (Some / Option setters). Default: false.

If the engine should gracefully shut down when queue processing encounters unexpected errors.

pub fn maybe_graceful_shutdown_on_error( self, value: Option<bool>, ) -> LiveRiskEngineConfigBuilder<SetGracefulShutdownOnError<S>>
where S::GracefulShutdownOnError: IsUnset,

Optional (Some / Option setters). Default: false.

If the engine should gracefully shut down when queue processing encounters unexpected errors.

pub fn qsize(self, value: u32) -> LiveRiskEngineConfigBuilder<SetQsize<S>>
where S::Qsize: IsUnset,

Optional (Some / Option setters). Default: 100_000.

The queue size for the engine’s internal queue buffers.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default.

pub fn maybe_qsize( self, value: Option<u32>, ) -> LiveRiskEngineConfigBuilder<SetQsize<S>>
where S::Qsize: IsUnset,

Optional (Some / Option setters). Default: 100_000.

The queue size for the engine’s internal queue buffers.

Not implemented on the current live runtime; validate_runtime_support rejects any value other than the default.