pub struct LiveExecEngineConfigBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> LiveExecEngineConfigBuilder<S>
impl<S: State> LiveExecEngineConfigBuilder<S>
Sourcepub fn build(self) -> LiveExecEngineConfigwhere
S: IsComplete,
pub fn build(self) -> LiveExecEngineConfigwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn load_cache(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetLoadCache<S>>where
S::LoadCache: IsUnset,
pub fn load_cache(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetLoadCache<S>>where
S::LoadCache: IsUnset,
Sourcepub fn maybe_load_cache(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetLoadCache<S>>where
S::LoadCache: IsUnset,
pub fn maybe_load_cache(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetLoadCache<S>>where
S::LoadCache: IsUnset,
Sourcepub fn snapshot_orders(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetSnapshotOrders<S>>where
S::SnapshotOrders: IsUnset,
pub fn snapshot_orders(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetSnapshotOrders<S>>where
S::SnapshotOrders: IsUnset,
Optional (Some / Option setters).
Default: false.
If order state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Sourcepub fn maybe_snapshot_orders(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetSnapshotOrders<S>>where
S::SnapshotOrders: IsUnset,
pub fn maybe_snapshot_orders(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetSnapshotOrders<S>>where
S::SnapshotOrders: IsUnset,
Optional (Some / Option setters).
Default: false.
If order state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Sourcepub fn snapshot_positions(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositions<S>>where
S::SnapshotPositions: IsUnset,
pub fn snapshot_positions(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositions<S>>where
S::SnapshotPositions: IsUnset,
Optional (Some / Option setters).
Default: false.
If position state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Sourcepub fn maybe_snapshot_positions(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositions<S>>where
S::SnapshotPositions: IsUnset,
pub fn maybe_snapshot_positions(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositions<S>>where
S::SnapshotPositions: IsUnset,
Optional (Some / Option setters).
Default: false.
If position state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Sourcepub fn snapshot_positions_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>where
S::SnapshotPositionsIntervalSecs: IsUnset,
pub fn snapshot_positions_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>where
S::SnapshotPositionsIntervalSecs: IsUnset,
Sourcepub fn maybe_snapshot_positions_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>where
S::SnapshotPositionsIntervalSecs: IsUnset,
pub fn maybe_snapshot_positions_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>where
S::SnapshotPositionsIntervalSecs: IsUnset,
Sourcepub fn external_clients(
self,
value: Vec<ClientId>,
) -> LiveExecEngineConfigBuilder<SetExternalClients<S>>where
S::ExternalClients: IsUnset,
pub fn external_clients(
self,
value: Vec<ClientId>,
) -> LiveExecEngineConfigBuilder<SetExternalClients<S>>where
S::ExternalClients: IsUnset,
Sourcepub fn maybe_external_clients(
self,
value: Option<Vec<ClientId>>,
) -> LiveExecEngineConfigBuilder<SetExternalClients<S>>where
S::ExternalClients: IsUnset,
pub fn maybe_external_clients(
self,
value: Option<Vec<ClientId>>,
) -> LiveExecEngineConfigBuilder<SetExternalClients<S>>where
S::ExternalClients: IsUnset,
Sourcepub fn debug(self, value: bool) -> LiveExecEngineConfigBuilder<SetDebug<S>>where
S::Debug: IsUnset,
pub fn debug(self, value: bool) -> LiveExecEngineConfigBuilder<SetDebug<S>>where
S::Debug: IsUnset,
Sourcepub fn maybe_debug(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetDebug<S>>where
S::Debug: IsUnset,
pub fn maybe_debug(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetDebug<S>>where
S::Debug: IsUnset,
Sourcepub fn reconciliation(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetReconciliation<S>>where
S::Reconciliation: IsUnset,
pub fn reconciliation(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetReconciliation<S>>where
S::Reconciliation: IsUnset,
Sourcepub fn maybe_reconciliation(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetReconciliation<S>>where
S::Reconciliation: IsUnset,
pub fn maybe_reconciliation(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetReconciliation<S>>where
S::Reconciliation: IsUnset,
Sourcepub fn reconciliation_startup_delay_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetReconciliationStartupDelaySecs<S>>where
S::ReconciliationStartupDelaySecs: IsUnset,
pub fn reconciliation_startup_delay_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetReconciliationStartupDelaySecs<S>>where
S::ReconciliationStartupDelaySecs: IsUnset,
Sourcepub fn maybe_reconciliation_startup_delay_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetReconciliationStartupDelaySecs<S>>where
S::ReconciliationStartupDelaySecs: IsUnset,
pub fn maybe_reconciliation_startup_delay_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetReconciliationStartupDelaySecs<S>>where
S::ReconciliationStartupDelaySecs: IsUnset,
Sourcepub fn reconciliation_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetReconciliationLookbackMins<S>>where
S::ReconciliationLookbackMins: IsUnset,
pub fn reconciliation_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetReconciliationLookbackMins<S>>where
S::ReconciliationLookbackMins: IsUnset,
Sourcepub fn maybe_reconciliation_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetReconciliationLookbackMins<S>>where
S::ReconciliationLookbackMins: IsUnset,
pub fn maybe_reconciliation_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetReconciliationLookbackMins<S>>where
S::ReconciliationLookbackMins: IsUnset,
Sourcepub fn reconciliation_instrument_ids(
self,
value: Vec<String>,
) -> LiveExecEngineConfigBuilder<SetReconciliationInstrumentIds<S>>where
S::ReconciliationInstrumentIds: IsUnset,
pub fn reconciliation_instrument_ids(
self,
value: Vec<String>,
) -> LiveExecEngineConfigBuilder<SetReconciliationInstrumentIds<S>>where
S::ReconciliationInstrumentIds: IsUnset,
Sourcepub fn maybe_reconciliation_instrument_ids(
self,
value: Option<Vec<String>>,
) -> LiveExecEngineConfigBuilder<SetReconciliationInstrumentIds<S>>where
S::ReconciliationInstrumentIds: IsUnset,
pub fn maybe_reconciliation_instrument_ids(
self,
value: Option<Vec<String>>,
) -> LiveExecEngineConfigBuilder<SetReconciliationInstrumentIds<S>>where
S::ReconciliationInstrumentIds: IsUnset,
Sourcepub fn filter_unclaimed_external_orders(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetFilterUnclaimedExternalOrders<S>>where
S::FilterUnclaimedExternalOrders: IsUnset,
pub fn filter_unclaimed_external_orders(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetFilterUnclaimedExternalOrders<S>>where
S::FilterUnclaimedExternalOrders: IsUnset,
Sourcepub fn maybe_filter_unclaimed_external_orders(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetFilterUnclaimedExternalOrders<S>>where
S::FilterUnclaimedExternalOrders: IsUnset,
pub fn maybe_filter_unclaimed_external_orders(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetFilterUnclaimedExternalOrders<S>>where
S::FilterUnclaimedExternalOrders: IsUnset,
Sourcepub fn filter_position_reports(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetFilterPositionReports<S>>where
S::FilterPositionReports: IsUnset,
pub fn filter_position_reports(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetFilterPositionReports<S>>where
S::FilterPositionReports: IsUnset,
Sourcepub fn maybe_filter_position_reports(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetFilterPositionReports<S>>where
S::FilterPositionReports: IsUnset,
pub fn maybe_filter_position_reports(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetFilterPositionReports<S>>where
S::FilterPositionReports: IsUnset,
Sourcepub fn filtered_client_order_ids(
self,
value: Vec<String>,
) -> LiveExecEngineConfigBuilder<SetFilteredClientOrderIds<S>>where
S::FilteredClientOrderIds: IsUnset,
pub fn filtered_client_order_ids(
self,
value: Vec<String>,
) -> LiveExecEngineConfigBuilder<SetFilteredClientOrderIds<S>>where
S::FilteredClientOrderIds: IsUnset,
Sourcepub fn maybe_filtered_client_order_ids(
self,
value: Option<Vec<String>>,
) -> LiveExecEngineConfigBuilder<SetFilteredClientOrderIds<S>>where
S::FilteredClientOrderIds: IsUnset,
pub fn maybe_filtered_client_order_ids(
self,
value: Option<Vec<String>>,
) -> LiveExecEngineConfigBuilder<SetFilteredClientOrderIds<S>>where
S::FilteredClientOrderIds: IsUnset,
Sourcepub fn generate_missing_orders(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetGenerateMissingOrders<S>>where
S::GenerateMissingOrders: IsUnset,
pub fn generate_missing_orders(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetGenerateMissingOrders<S>>where
S::GenerateMissingOrders: IsUnset,
Sourcepub fn maybe_generate_missing_orders(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetGenerateMissingOrders<S>>where
S::GenerateMissingOrders: IsUnset,
pub fn maybe_generate_missing_orders(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetGenerateMissingOrders<S>>where
S::GenerateMissingOrders: IsUnset,
Sourcepub fn inflight_check_interval_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetInflightCheckIntervalMs<S>>where
S::InflightCheckIntervalMs: IsUnset,
pub fn inflight_check_interval_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetInflightCheckIntervalMs<S>>where
S::InflightCheckIntervalMs: IsUnset,
Sourcepub fn maybe_inflight_check_interval_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetInflightCheckIntervalMs<S>>where
S::InflightCheckIntervalMs: IsUnset,
pub fn maybe_inflight_check_interval_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetInflightCheckIntervalMs<S>>where
S::InflightCheckIntervalMs: IsUnset,
Sourcepub fn inflight_check_threshold_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetInflightCheckThresholdMs<S>>where
S::InflightCheckThresholdMs: IsUnset,
pub fn inflight_check_threshold_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetInflightCheckThresholdMs<S>>where
S::InflightCheckThresholdMs: IsUnset,
Sourcepub fn maybe_inflight_check_threshold_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetInflightCheckThresholdMs<S>>where
S::InflightCheckThresholdMs: IsUnset,
pub fn maybe_inflight_check_threshold_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetInflightCheckThresholdMs<S>>where
S::InflightCheckThresholdMs: IsUnset,
Sourcepub fn inflight_check_retries(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetInflightCheckRetries<S>>where
S::InflightCheckRetries: IsUnset,
pub fn inflight_check_retries(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetInflightCheckRetries<S>>where
S::InflightCheckRetries: IsUnset,
Sourcepub fn maybe_inflight_check_retries(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetInflightCheckRetries<S>>where
S::InflightCheckRetries: IsUnset,
pub fn maybe_inflight_check_retries(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetInflightCheckRetries<S>>where
S::InflightCheckRetries: IsUnset,
Sourcepub fn open_check_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetOpenCheckIntervalSecs<S>>where
S::OpenCheckIntervalSecs: IsUnset,
pub fn open_check_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetOpenCheckIntervalSecs<S>>where
S::OpenCheckIntervalSecs: IsUnset,
Sourcepub fn maybe_open_check_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckIntervalSecs<S>>where
S::OpenCheckIntervalSecs: IsUnset,
pub fn maybe_open_check_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckIntervalSecs<S>>where
S::OpenCheckIntervalSecs: IsUnset,
Sourcepub fn open_check_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetOpenCheckLookbackMins<S>>where
S::OpenCheckLookbackMins: IsUnset,
pub fn open_check_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetOpenCheckLookbackMins<S>>where
S::OpenCheckLookbackMins: IsUnset,
Sourcepub fn maybe_open_check_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckLookbackMins<S>>where
S::OpenCheckLookbackMins: IsUnset,
pub fn maybe_open_check_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckLookbackMins<S>>where
S::OpenCheckLookbackMins: IsUnset,
Sourcepub fn open_check_threshold_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetOpenCheckThresholdMs<S>>where
S::OpenCheckThresholdMs: IsUnset,
pub fn open_check_threshold_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetOpenCheckThresholdMs<S>>where
S::OpenCheckThresholdMs: IsUnset,
Sourcepub fn maybe_open_check_threshold_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckThresholdMs<S>>where
S::OpenCheckThresholdMs: IsUnset,
pub fn maybe_open_check_threshold_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckThresholdMs<S>>where
S::OpenCheckThresholdMs: IsUnset,
Sourcepub fn open_check_missing_retries(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetOpenCheckMissingRetries<S>>where
S::OpenCheckMissingRetries: IsUnset,
pub fn open_check_missing_retries(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetOpenCheckMissingRetries<S>>where
S::OpenCheckMissingRetries: IsUnset,
Sourcepub fn maybe_open_check_missing_retries(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckMissingRetries<S>>where
S::OpenCheckMissingRetries: IsUnset,
pub fn maybe_open_check_missing_retries(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckMissingRetries<S>>where
S::OpenCheckMissingRetries: IsUnset,
Sourcepub fn open_check_open_only(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetOpenCheckOpenOnly<S>>where
S::OpenCheckOpenOnly: IsUnset,
pub fn open_check_open_only(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetOpenCheckOpenOnly<S>>where
S::OpenCheckOpenOnly: IsUnset,
Sourcepub fn maybe_open_check_open_only(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckOpenOnly<S>>where
S::OpenCheckOpenOnly: IsUnset,
pub fn maybe_open_check_open_only(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetOpenCheckOpenOnly<S>>where
S::OpenCheckOpenOnly: IsUnset,
Sourcepub fn max_single_order_queries_per_cycle(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetMaxSingleOrderQueriesPerCycle<S>>where
S::MaxSingleOrderQueriesPerCycle: IsUnset,
pub fn max_single_order_queries_per_cycle(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetMaxSingleOrderQueriesPerCycle<S>>where
S::MaxSingleOrderQueriesPerCycle: IsUnset,
Sourcepub fn maybe_max_single_order_queries_per_cycle(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetMaxSingleOrderQueriesPerCycle<S>>where
S::MaxSingleOrderQueriesPerCycle: IsUnset,
pub fn maybe_max_single_order_queries_per_cycle(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetMaxSingleOrderQueriesPerCycle<S>>where
S::MaxSingleOrderQueriesPerCycle: IsUnset,
Sourcepub fn single_order_query_delay_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetSingleOrderQueryDelayMs<S>>where
S::SingleOrderQueryDelayMs: IsUnset,
pub fn single_order_query_delay_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetSingleOrderQueryDelayMs<S>>where
S::SingleOrderQueryDelayMs: IsUnset,
Sourcepub fn maybe_single_order_query_delay_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetSingleOrderQueryDelayMs<S>>where
S::SingleOrderQueryDelayMs: IsUnset,
pub fn maybe_single_order_query_delay_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetSingleOrderQueryDelayMs<S>>where
S::SingleOrderQueryDelayMs: IsUnset,
Sourcepub fn position_check_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetPositionCheckIntervalSecs<S>>where
S::PositionCheckIntervalSecs: IsUnset,
pub fn position_check_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetPositionCheckIntervalSecs<S>>where
S::PositionCheckIntervalSecs: IsUnset,
Sourcepub fn maybe_position_check_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckIntervalSecs<S>>where
S::PositionCheckIntervalSecs: IsUnset,
pub fn maybe_position_check_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckIntervalSecs<S>>where
S::PositionCheckIntervalSecs: IsUnset,
Sourcepub fn position_check_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPositionCheckLookbackMins<S>>where
S::PositionCheckLookbackMins: IsUnset,
pub fn position_check_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPositionCheckLookbackMins<S>>where
S::PositionCheckLookbackMins: IsUnset,
Sourcepub fn maybe_position_check_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckLookbackMins<S>>where
S::PositionCheckLookbackMins: IsUnset,
pub fn maybe_position_check_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckLookbackMins<S>>where
S::PositionCheckLookbackMins: IsUnset,
Sourcepub fn position_check_threshold_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPositionCheckThresholdMs<S>>where
S::PositionCheckThresholdMs: IsUnset,
pub fn position_check_threshold_ms(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPositionCheckThresholdMs<S>>where
S::PositionCheckThresholdMs: IsUnset,
Sourcepub fn maybe_position_check_threshold_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckThresholdMs<S>>where
S::PositionCheckThresholdMs: IsUnset,
pub fn maybe_position_check_threshold_ms(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckThresholdMs<S>>where
S::PositionCheckThresholdMs: IsUnset,
Sourcepub fn position_check_retries(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPositionCheckRetries<S>>where
S::PositionCheckRetries: IsUnset,
pub fn position_check_retries(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPositionCheckRetries<S>>where
S::PositionCheckRetries: IsUnset,
Sourcepub fn maybe_position_check_retries(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckRetries<S>>where
S::PositionCheckRetries: IsUnset,
pub fn maybe_position_check_retries(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPositionCheckRetries<S>>where
S::PositionCheckRetries: IsUnset,
Sourcepub fn purge_closed_orders_interval_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>where
S::PurgeClosedOrdersIntervalMins: IsUnset,
pub fn purge_closed_orders_interval_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>where
S::PurgeClosedOrdersIntervalMins: IsUnset,
Sourcepub fn maybe_purge_closed_orders_interval_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>where
S::PurgeClosedOrdersIntervalMins: IsUnset,
pub fn maybe_purge_closed_orders_interval_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>where
S::PurgeClosedOrdersIntervalMins: IsUnset,
Sourcepub fn purge_closed_orders_buffer_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>where
S::PurgeClosedOrdersBufferMins: IsUnset,
pub fn purge_closed_orders_buffer_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>where
S::PurgeClosedOrdersBufferMins: IsUnset,
Sourcepub fn maybe_purge_closed_orders_buffer_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>where
S::PurgeClosedOrdersBufferMins: IsUnset,
pub fn maybe_purge_closed_orders_buffer_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>where
S::PurgeClosedOrdersBufferMins: IsUnset,
Sourcepub fn purge_closed_positions_interval_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>where
S::PurgeClosedPositionsIntervalMins: IsUnset,
pub fn purge_closed_positions_interval_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>where
S::PurgeClosedPositionsIntervalMins: IsUnset,
Sourcepub fn maybe_purge_closed_positions_interval_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>where
S::PurgeClosedPositionsIntervalMins: IsUnset,
pub fn maybe_purge_closed_positions_interval_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>where
S::PurgeClosedPositionsIntervalMins: IsUnset,
Sourcepub fn purge_closed_positions_buffer_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>where
S::PurgeClosedPositionsBufferMins: IsUnset,
pub fn purge_closed_positions_buffer_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>where
S::PurgeClosedPositionsBufferMins: IsUnset,
Sourcepub fn maybe_purge_closed_positions_buffer_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>where
S::PurgeClosedPositionsBufferMins: IsUnset,
pub fn maybe_purge_closed_positions_buffer_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>where
S::PurgeClosedPositionsBufferMins: IsUnset,
Sourcepub fn purge_account_events_interval_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>where
S::PurgeAccountEventsIntervalMins: IsUnset,
pub fn purge_account_events_interval_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>where
S::PurgeAccountEventsIntervalMins: IsUnset,
Sourcepub fn maybe_purge_account_events_interval_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>where
S::PurgeAccountEventsIntervalMins: IsUnset,
pub fn maybe_purge_account_events_interval_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>where
S::PurgeAccountEventsIntervalMins: IsUnset,
Sourcepub fn purge_account_events_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>where
S::PurgeAccountEventsLookbackMins: IsUnset,
pub fn purge_account_events_lookback_mins(
self,
value: u32,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>where
S::PurgeAccountEventsLookbackMins: IsUnset,
Sourcepub fn maybe_purge_account_events_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>where
S::PurgeAccountEventsLookbackMins: IsUnset,
pub fn maybe_purge_account_events_lookback_mins(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>where
S::PurgeAccountEventsLookbackMins: IsUnset,
Sourcepub fn purge_from_database(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetPurgeFromDatabase<S>>where
S::PurgeFromDatabase: IsUnset,
pub fn purge_from_database(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetPurgeFromDatabase<S>>where
S::PurgeFromDatabase: IsUnset,
Sourcepub fn maybe_purge_from_database(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetPurgeFromDatabase<S>>where
S::PurgeFromDatabase: IsUnset,
pub fn maybe_purge_from_database(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetPurgeFromDatabase<S>>where
S::PurgeFromDatabase: IsUnset,
Sourcepub fn own_books_audit_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetOwnBooksAuditIntervalSecs<S>>where
S::OwnBooksAuditIntervalSecs: IsUnset,
pub fn own_books_audit_interval_secs(
self,
value: f64,
) -> LiveExecEngineConfigBuilder<SetOwnBooksAuditIntervalSecs<S>>where
S::OwnBooksAuditIntervalSecs: IsUnset,
Sourcepub fn maybe_own_books_audit_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetOwnBooksAuditIntervalSecs<S>>where
S::OwnBooksAuditIntervalSecs: IsUnset,
pub fn maybe_own_books_audit_interval_secs(
self,
value: Option<f64>,
) -> LiveExecEngineConfigBuilder<SetOwnBooksAuditIntervalSecs<S>>where
S::OwnBooksAuditIntervalSecs: IsUnset,
Sourcepub fn graceful_shutdown_on_error(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetGracefulShutdownOnError<S>>where
S::GracefulShutdownOnError: IsUnset,
pub fn graceful_shutdown_on_error(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetGracefulShutdownOnError<S>>where
S::GracefulShutdownOnError: IsUnset,
Sourcepub fn maybe_graceful_shutdown_on_error(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetGracefulShutdownOnError<S>>where
S::GracefulShutdownOnError: IsUnset,
pub fn maybe_graceful_shutdown_on_error(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetGracefulShutdownOnError<S>>where
S::GracefulShutdownOnError: IsUnset,
Sourcepub fn qsize(self, value: u32) -> LiveExecEngineConfigBuilder<SetQsize<S>>where
S::Qsize: IsUnset,
pub fn qsize(self, value: u32) -> LiveExecEngineConfigBuilder<SetQsize<S>>where
S::Qsize: IsUnset,
Sourcepub fn maybe_qsize(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetQsize<S>>where
S::Qsize: IsUnset,
pub fn maybe_qsize(
self,
value: Option<u32>,
) -> LiveExecEngineConfigBuilder<SetQsize<S>>where
S::Qsize: IsUnset,
Sourcepub fn allow_overfills(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetAllowOverfills<S>>where
S::AllowOverfills: IsUnset,
pub fn allow_overfills(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetAllowOverfills<S>>where
S::AllowOverfills: IsUnset,
Sourcepub fn maybe_allow_overfills(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetAllowOverfills<S>>where
S::AllowOverfills: IsUnset,
pub fn maybe_allow_overfills(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetAllowOverfills<S>>where
S::AllowOverfills: IsUnset,
Sourcepub fn manage_own_order_books(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetManageOwnOrderBooks<S>>where
S::ManageOwnOrderBooks: IsUnset,
pub fn manage_own_order_books(
self,
value: bool,
) -> LiveExecEngineConfigBuilder<SetManageOwnOrderBooks<S>>where
S::ManageOwnOrderBooks: IsUnset,
Sourcepub fn maybe_manage_own_order_books(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetManageOwnOrderBooks<S>>where
S::ManageOwnOrderBooks: IsUnset,
pub fn maybe_manage_own_order_books(
self,
value: Option<bool>,
) -> LiveExecEngineConfigBuilder<SetManageOwnOrderBooks<S>>where
S::ManageOwnOrderBooks: IsUnset,